.. _satdet:

**************************
Satellite Trails Detection
**************************

.. currentmodule:: acstools.satdet

.. automodule:: acstools.satdet
   :members:


Version
-------

.. autodata:: acstools.satdet.__version__
.. autodata:: acstools.satdet.__vdate__


Author
------

.. autodata:: acstools.satdet.__author__
